IoT Relay - pywws version
==================================
Release v1.0.1

**Install**

pip install iotrelay-pywws



See http://jim-easterbrook.github.io/pywws/doc/en/html/index.html more on pywws.
